@@ -12,6 +12,17 @@ class RequestError(HomeWizardEnergyException):
     """
 
 
+class ResponseError(HomeWizardEnergyException):
+    """API responded unexpected."""
+
+
+class NotFoundError(HomeWizardEnergyException):
+    """Request not found.
+
+    Raised when API responds with '404'
+    """
+
+
 class InvalidStateError(HomeWizardEnergyException):
     """Raised when the device is not in the correct state."""
 
@@ -22,3 +33,7 @@ class UnsupportedError(HomeWizardEnergyException):
 
 class DisabledError(HomeWizardEnergyException):
     """Raised when device API is disabled. User has to enable API in app."""
+
+
+class UnauthorizedError(HomeWizardEnergyException):
+    """Raised when request is not authorized."""
